Contents Menu Expand Light mode Dark mode Auto light/dark, in light mode Auto light/dark, in dark mode Skip to content
dpnp
Data Parallel Extension for NumPy
0.21.0dev0+59.g0dd5482d6fa documentation
dpnp
Data Parallel Extension for NumPy
0.21.0dev0+59.g0dd5482d6fa documentation

Contents:

  • Overview
  • Quick Start Guide
  • API Reference
    • The N-dimensional array (ndarray)
      • dpnp.ndarray
      • dpnp.dpnp_array.dpnp_array
      • dpnp.ndarray
      • dpnp.ndarray.flags
      • dpnp.ndarray.shape
      • dpnp.ndarray.strides
      • dpnp.ndarray.ndim
      • dpnp.ndarray.data
      • dpnp.ndarray.size
      • dpnp.ndarray.itemsize
      • dpnp.ndarray.nbytes
      • dpnp.ndarray.device
      • dpnp.ndarray.sycl_context
      • dpnp.ndarray.sycl_device
      • dpnp.ndarray.sycl_queue
      • dpnp.ndarray.usm_type
      • dpnp.ndarray.dtype
      • dpnp.ndarray.T
      • dpnp.ndarray.mT
      • dpnp.ndarray.real
      • dpnp.ndarray.imag
      • dpnp.ndarray.flat
      • dpnp.ndarray.__sycl_usm_array_interface__
      • dpnp.ndarray.__usm_ndarray__
      • dpnp.ndarray.item
      • dpnp.ndarray.tolist
      • dpnp.ndarray.tobytes
      • dpnp.ndarray.tofile
      • dpnp.ndarray.astype
      • dpnp.ndarray.copy
      • dpnp.ndarray.view
      • dpnp.ndarray.fill
      • dpnp.ndarray.get_array
      • dpnp.ndarray.reshape
      • dpnp.ndarray.transpose
      • dpnp.ndarray.swapaxes
      • dpnp.ndarray.flatten
      • dpnp.ndarray.ravel
      • dpnp.ndarray.squeeze
      • dpnp.ndarray.take
      • dpnp.ndarray.put
      • dpnp.ndarray.repeat
      • dpnp.ndarray.choose
      • dpnp.ndarray.sort
      • dpnp.ndarray.argsort
      • dpnp.ndarray.partition
      • dpnp.ndarray.searchsorted
      • dpnp.ndarray.nonzero
      • dpnp.ndarray.compress
      • dpnp.ndarray.diagonal
      • dpnp.ndarray.max
      • dpnp.ndarray.argmax
      • dpnp.ndarray.min
      • dpnp.ndarray.argmin
      • dpnp.ndarray.clip
      • dpnp.ndarray.conj
      • dpnp.ndarray.conjugate
      • dpnp.ndarray.round
      • dpnp.ndarray.trace
      • dpnp.ndarray.sum
      • dpnp.ndarray.cumsum
      • dpnp.ndarray.mean
      • dpnp.ndarray.var
      • dpnp.ndarray.std
      • dpnp.ndarray.prod
      • dpnp.ndarray.cumprod
      • dpnp.ndarray.all
      • dpnp.ndarray.any
      • dpnp.ndarray.__lt__
      • dpnp.ndarray.__le__
      • dpnp.ndarray.__gt__
      • dpnp.ndarray.__ge__
      • dpnp.ndarray.__eq__
      • dpnp.ndarray.__ne__
      • dpnp.ndarray.__bool__
      • dpnp.ndarray.__neg__
      • dpnp.ndarray.__pos__
      • dpnp.ndarray.__abs__
      • dpnp.ndarray.__invert__
      • dpnp.ndarray.__add__
      • dpnp.ndarray.__sub__
      • dpnp.ndarray.__mul__
      • dpnp.ndarray.__truediv__
      • dpnp.ndarray.__floordiv__
      • dpnp.ndarray.__mod__
      • dpnp.ndarray.__divmod__
      • dpnp.ndarray.__pow__
      • dpnp.ndarray.__lshift__
      • dpnp.ndarray.__rshift__
      • dpnp.ndarray.__and__
      • dpnp.ndarray.__or__
      • dpnp.ndarray.__xor__
      • dpnp.ndarray.__radd__
      • dpnp.ndarray.__rsub__
      • dpnp.ndarray.__rmul__
      • dpnp.ndarray.__rtruediv__
      • dpnp.ndarray.__rfloordiv__
      • dpnp.ndarray.__rmod__
      • dpnp.ndarray.__rdivmod__
      • dpnp.ndarray.__rpow__
      • dpnp.ndarray.__rlshift__
      • dpnp.ndarray.__rrshift__
      • dpnp.ndarray.__rand__
      • dpnp.ndarray.__ror__
      • dpnp.ndarray.__rxor__
      • dpnp.ndarray.__iadd__
      • dpnp.ndarray.__isub__
      • dpnp.ndarray.__imul__
      • dpnp.ndarray.__itruediv__
      • dpnp.ndarray.__ifloordiv__
      • dpnp.ndarray.__imod__
      • dpnp.ndarray.__ipow__
      • dpnp.ndarray.__ilshift__
      • dpnp.ndarray.__irshift__
      • dpnp.ndarray.__iand__
      • dpnp.ndarray.__ior__
      • dpnp.ndarray.__ixor__
      • dpnp.ndarray.__matmul__
      • dpnp.ndarray.__rmatmul__
      • dpnp.ndarray.__imatmul__
      • dpnp.ndarray.__copy__
      • dpnp.ndarray.__new__
      • dpnp.ndarray.__array__
      • dpnp.ndarray.__array_namespace__
      • dpnp.ndarray.__dlpack__
      • dpnp.ndarray.__dlpack_device__
      • dpnp.ndarray.__len__
      • dpnp.ndarray.__iter__
      • dpnp.ndarray.__getitem__
      • dpnp.ndarray.__setitem__
      • dpnp.ndarray.__contains__
      • dpnp.ndarray.__bytes__
      • dpnp.ndarray.__index__
      • dpnp.ndarray.__int__
      • dpnp.ndarray.__float__
      • dpnp.ndarray.__complex__
      • dpnp.ndarray.__str__
      • dpnp.ndarray.__repr__
      • dpnp.ndarray.__format__
    • Universal functions
      • dpnp.add
      • dpnp.subtract
      • dpnp.multiply
      • dpnp.matmul
      • dpnp.divide
      • dpnp.logaddexp
      • dpnp.logaddexp2
      • dpnp.true_divide
      • dpnp.floor_divide
      • dpnp.negative
      • dpnp.positive
      • dpnp.power
      • dpnp.pow
      • dpnp.float_power
      • dpnp.remainder
      • dpnp.mod
      • dpnp.fmod
      • dpnp.divmod
      • dpnp.absolute
      • dpnp.fabs
      • dpnp.rint
      • dpnp.sign
      • dpnp.heaviside
      • dpnp.conj
      • dpnp.conjugate
      • dpnp.exp
      • dpnp.exp2
      • dpnp.log
      • dpnp.log2
      • dpnp.log10
      • dpnp.expm1
      • dpnp.log1p
      • dpnp.proj
      • dpnp.sqrt
      • dpnp.square
      • dpnp.cbrt
      • dpnp.reciprocal
      • dpnp.rsqrt
      • dpnp.gcd
      • dpnp.lcm
      • dpnp.sin
      • dpnp.cos
      • dpnp.tan
      • dpnp.arcsin
      • dpnp.asin
      • dpnp.arccos
      • dpnp.acos
      • dpnp.arctan
      • dpnp.atan
      • dpnp.arctan2
      • dpnp.atan2
      • dpnp.hypot
      • dpnp.sinh
      • dpnp.cosh
      • dpnp.tanh
      • dpnp.arcsinh
      • dpnp.asinh
      • dpnp.arccosh
      • dpnp.acosh
      • dpnp.arctanh
      • dpnp.atanh
      • dpnp.degrees
      • dpnp.radians
      • dpnp.deg2rad
      • dpnp.rad2deg
      • dpnp.bitwise_and
      • dpnp.bitwise_not
      • dpnp.bitwise_or
      • dpnp.bitwise_xor
      • dpnp.invert
      • dpnp.bitwise_invert
      • dpnp.left_shift
      • dpnp.bitwise_left_shift
      • dpnp.right_shift
      • dpnp.bitwise_right_shift
      • dpnp.bitwise_count
      • dpnp.greater
      • dpnp.greater_equal
      • dpnp.less
      • dpnp.less_equal
      • dpnp.not_equal
      • dpnp.equal
      • dpnp.logical_and
      • dpnp.logical_or
      • dpnp.logical_xor
      • dpnp.logical_not
      • dpnp.maximum
      • dpnp.minimum
      • dpnp.fmax
      • dpnp.fmin
      • dpnp.isfinite
      • dpnp.isinf
      • dpnp.isnan
      • dpnp.fabs
      • dpnp.signbit
      • dpnp.copysign
      • dpnp.nextafter
      • dpnp.spacing
      • dpnp.modf
      • dpnp.ldexp
      • dpnp.frexp
      • dpnp.fmod
      • dpnp.floor
      • dpnp.ceil
      • dpnp.trunc
    • Routines (NumPy)
      • Constants
      • Array creation routines
        • dpnp.empty
        • dpnp.empty_like
        • dpnp.eye
        • dpnp.identity
        • dpnp.ones
        • dpnp.ones_like
        • dpnp.zeros
        • dpnp.zeros_like
        • dpnp.full
        • dpnp.full_like
        • dpnp.array
        • dpnp.asarray
        • dpnp.asanyarray
        • dpnp.ascontiguousarray
        • dpnp.astype
        • dpnp.copy
        • dpnp.frombuffer
        • dpnp.from_dlpack
        • dpnp.fromfile
        • dpnp.fromfunction
        • dpnp.fromiter
        • dpnp.fromstring
        • dpnp.loadtxt
        • dpnp.arange
        • dpnp.linspace
        • dpnp.logspace
        • dpnp.geomspace
        • dpnp.meshgrid
        • dpnp.mgrid
        • dpnp.ogrid
        • dpnp.diag
        • dpnp.diagflat
        • dpnp.tri
        • dpnp.tril
        • dpnp.triu
        • dpnp.vander
      • Array manipulation routines
        • dpnp.copyto
        • dpnp.ndim
        • dpnp.shape
        • dpnp.size
        • dpnp.reshape
        • dpnp.ravel
        • dpnp.ndarray.flat
        • dpnp.ndarray.flatten
        • dpnp.moveaxis
        • dpnp.rollaxis
        • dpnp.swapaxes
        • dpnp.ndarray.T
        • dpnp.transpose
        • dpnp.permute_dims
        • dpnp.matrix_transpose
        • dpnp.atleast_1d
        • dpnp.atleast_2d
        • dpnp.atleast_3d
        • dpnp.broadcast_to
        • dpnp.broadcast_arrays
        • dpnp.expand_dims
        • dpnp.squeeze
        • dpnp.asarray
        • dpnp.asanyarray
        • dpnp.asnumpy
        • dpnp.asfortranarray
        • dpnp.ascontiguousarray
        • dpnp.asarray_chkfinite
        • dpnp.require
        • dpnp.concatenate
        • dpnp.concat
        • dpnp.stack
        • dpnp.vstack
        • dpnp.hstack
        • dpnp.dstack
        • dpnp.column_stack
        • dpnp.row_stack
        • dpnp.split
        • dpnp.array_split
        • dpnp.dsplit
        • dpnp.hsplit
        • dpnp.vsplit
        • dpnp.unstack
        • dpnp.tile
        • dpnp.repeat
        • dpnp.delete
        • dpnp.insert
        • dpnp.append
        • dpnp.resize
        • dpnp.trim_zeros
        • dpnp.pad
        • dpnp.flip
        • dpnp.fliplr
        • dpnp.flipud
        • dpnp.roll
        • dpnp.rot90
      • Bit-wise operations
        • dpnp.bitwise_and
        • dpnp.bitwise_not
        • dpnp.bitwise_or
        • dpnp.bitwise_xor
        • dpnp.invert
        • dpnp.bitwise_invert
        • dpnp.left_shift
        • dpnp.bitwise_left_shift
        • dpnp.right_shift
        • dpnp.bitwise_right_shift
        • dpnp.bitwise_count
        • dpnp.binary_repr
      • Data type routines
        • dpnp.can_cast
        • dpnp.result_type
        • dpnp.common_type
        • dpnp.dtype
        • dpnp.finfo
        • dpnp.iinfo
        • dpnp.isdtype
        • dpnp.issubdtype
      • Exceptions and Warnings
      • Discrete Fourier Transform (dpnp.fft)
        • dpnp.fft.fft
        • dpnp.fft.ifft
        • dpnp.fft.fft2
        • dpnp.fft.ifft2
        • dpnp.fft.fftn
        • dpnp.fft.ifftn
        • dpnp.fft.rfft
        • dpnp.fft.irfft
        • dpnp.fft.rfft2
        • dpnp.fft.irfft2
        • dpnp.fft.rfftn
        • dpnp.fft.irfftn
        • dpnp.fft.hfft
        • dpnp.fft.ihfft
        • dpnp.fft.fftfreq
        • dpnp.fft.rfftfreq
        • dpnp.fft.fftshift
        • dpnp.fft.ifftshift
      • Functional programming
        • dpnp.apply_along_axis
        • dpnp.apply_over_axes
        • dpnp.piecewise
      • Input and output
        • dpnp.loadtxt
        • dpnp.fromstring
        • dpnp.ndarray.tofile
        • dpnp.ndarray.tolist
        • dpnp.fromfile
        • dpnp.ndarray.tofile
        • dpnp.binary_repr
      • Indexing routines
        • dpnp.nonzero
        • dpnp.where
        • dpnp.indices
        • dpnp.ix_
        • dpnp.ogrid
        • dpnp.ravel_multi_index
        • dpnp.unravel_index
        • dpnp.diag_indices
        • dpnp.diag_indices_from
        • dpnp.mask_indices
        • dpnp.tril_indices
        • dpnp.tril_indices_from
        • dpnp.triu_indices
        • dpnp.triu_indices_from
        • dpnp.take
        • dpnp.take_along_axis
        • dpnp.choose
        • dpnp.compress
        • dpnp.diag
        • dpnp.diagonal
        • dpnp.select
        • dpnp.place
        • dpnp.put
        • dpnp.put_along_axis
        • dpnp.putmask
        • dpnp.fill_diagonal
        • dpnp.ndindex
        • dpnp.flatiter
        • dpnp.iterable
      • Linear algebra (dpnp.linalg)
        • dpnp.dot
        • dpnp.linalg.multi_dot
        • dpnp.vdot
        • dpnp.vecdot
        • dpnp.linalg.vecdot
        • dpnp.inner
        • dpnp.outer
        • dpnp.linalg.outer
        • dpnp.matmul
        • dpnp.linalg.matmul
        • dpnp.matvec
        • dpnp.vecmat
        • dpnp.tensordot
        • dpnp.linalg.tensordot
        • dpnp.einsum
        • dpnp.einsum_path
        • dpnp.linalg.matrix_power
        • dpnp.kron
        • dpnp.linalg.cross
        • dpnp.linalg.cholesky
        • dpnp.linalg.qr
        • dpnp.linalg.svd
        • dpnp.linalg.svdvals
        • dpnp.linalg.eig
        • dpnp.linalg.eigh
        • dpnp.linalg.eigvals
        • dpnp.linalg.eigvalsh
        • dpnp.linalg.norm
        • dpnp.linalg.matrix_norm
        • dpnp.linalg.vector_norm
        • dpnp.linalg.cond
        • dpnp.linalg.det
        • dpnp.linalg.matrix_rank
        • dpnp.linalg.slogdet
        • dpnp.trace
        • dpnp.linalg.trace
        • dpnp.linalg.solve
        • dpnp.linalg.tensorsolve
        • dpnp.linalg.lstsq
        • dpnp.linalg.inv
        • dpnp.linalg.pinv
        • dpnp.linalg.tensorinv
        • dpnp.diagonal
        • dpnp.linalg.diagonal
        • dpnp.linalg.matrix_transpose
        • dpnp.linalg.LinAlgError
      • Logic functions
        • dpnp.all
        • dpnp.any
        • dpnp.isfinite
        • dpnp.isinf
        • dpnp.isnan
        • dpnp.isneginf
        • dpnp.isposinf
        • dpnp.iscomplex
        • dpnp.iscomplexobj
        • dpnp.isfortran
        • dpnp.isreal
        • dpnp.isrealobj
        • dpnp.isscalar
        • dpnp.logical_and
        • dpnp.logical_or
        • dpnp.logical_not
        • dpnp.logical_xor
        • dpnp.allclose
        • dpnp.isclose
        • dpnp.array_equal
        • dpnp.array_equiv
        • dpnp.greater
        • dpnp.greater_equal
        • dpnp.less
        • dpnp.less_equal
        • dpnp.equal
        • dpnp.not_equal
      • Mathematical functions
        • dpnp.sin
        • dpnp.cos
        • dpnp.tan
        • dpnp.arcsin
        • dpnp.asin
        • dpnp.arccos
        • dpnp.acos
        • dpnp.arctan
        • dpnp.atan
        • dpnp.hypot
        • dpnp.arctan2
        • dpnp.atan2
        • dpnp.degrees
        • dpnp.radians
        • dpnp.unwrap
        • dpnp.deg2rad
        • dpnp.rad2deg
        • dpnp.reduce_hypot
        • dpnp.sinh
        • dpnp.cosh
        • dpnp.tanh
        • dpnp.arcsinh
        • dpnp.asinh
        • dpnp.arccosh
        • dpnp.acosh
        • dpnp.arctanh
        • dpnp.atanh
        • dpnp.round
        • dpnp.around
        • dpnp.rint
        • dpnp.fix
        • dpnp.floor
        • dpnp.ceil
        • dpnp.trunc
        • dpnp.prod
        • dpnp.sum
        • dpnp.nanprod
        • dpnp.nansum
        • dpnp.cumulative_sum
        • dpnp.cumulative_prod
        • dpnp.cumprod
        • dpnp.cumsum
        • dpnp.nancumprod
        • dpnp.nancumsum
        • dpnp.diff
        • dpnp.ediff1d
        • dpnp.gradient
        • dpnp.cross
        • dpnp.trapezoid
        • dpnp.exp
        • dpnp.expm1
        • dpnp.exp2
        • dpnp.log
        • dpnp.log10
        • dpnp.log2
        • dpnp.log1p
        • dpnp.logaddexp
        • dpnp.logaddexp2
        • dpnp.logsumexp
        • dpnp.cumlogsumexp
        • dpnp.i0
        • dpnp.sinc
        • dpnp.signbit
        • dpnp.copysign
        • dpnp.frexp
        • dpnp.ldexp
        • dpnp.nextafter
        • dpnp.spacing
        • dpnp.lcm
        • dpnp.gcd
        • dpnp.add
        • dpnp.reciprocal
        • dpnp.positive
        • dpnp.negative
        • dpnp.multiply
        • dpnp.divide
        • dpnp.power
        • dpnp.pow
        • dpnp.subtract
        • dpnp.true_divide
        • dpnp.floor_divide
        • dpnp.float_power
        • dpnp.fmod
        • dpnp.mod
        • dpnp.modf
        • dpnp.remainder
        • dpnp.divmod
        • dpnp.angle
        • dpnp.real
        • dpnp.imag
        • dpnp.conj
        • dpnp.conjugate
        • dpnp.proj
        • dpnp.maximum
        • dpnp.max
        • dpnp.amax
        • dpnp.fmax
        • dpnp.nanmax
        • dpnp.minimum
        • dpnp.min
        • dpnp.amin
        • dpnp.fmin
        • dpnp.nanmin
        • dpnp.convolve
        • dpnp.clip
        • dpnp.sqrt
        • dpnp.cbrt
        • dpnp.square
        • dpnp.rsqrt
        • dpnp.abs
        • dpnp.absolute
        • dpnp.fabs
        • dpnp.sign
        • dpnp.heaviside
        • dpnp.nan_to_num
        • dpnp.real_if_close
        • dpnp.interp
      • Miscellaneous routines
        • dpnp.byte_bounds
        • dpnp.get_include
        • dpnp.broadcast_shapes
      • Random sampling (dpnp.random)
        • dpnp.random.rand
        • dpnp.random.randn
        • dpnp.random.randint
        • dpnp.random.random_integers
        • dpnp.random.random_sample
        • dpnp.random.random
        • dpnp.random.ranf
        • dpnp.random.sample
        • dpnp.random.choice
        • dpnp.random.bytes
        • dpnp.random.shuffle
        • dpnp.random.permutation
        • dpnp.random.beta
        • dpnp.random.binomial
        • dpnp.random.chisquare
        • dpnp.random.dirichlet
        • dpnp.random.exponential
        • dpnp.random.f
        • dpnp.random.gamma
        • dpnp.random.geometric
        • dpnp.random.gumbel
        • dpnp.random.hypergeometric
        • dpnp.random.laplace
        • dpnp.random.logistic
        • dpnp.random.lognormal
        • dpnp.random.logseries
        • dpnp.random.multinomial
        • dpnp.random.multivariate_normal
        • dpnp.random.negative_binomial
        • dpnp.random.noncentral_chisquare
        • dpnp.random.noncentral_f
        • dpnp.random.normal
        • dpnp.random.pareto
        • dpnp.random.poisson
        • dpnp.random.power
        • dpnp.random.rayleigh
        • dpnp.random.standard_cauchy
        • dpnp.random.standard_exponential
        • dpnp.random.standard_gamma
        • dpnp.random.standard_normal
        • dpnp.random.standard_t
        • dpnp.random.triangular
        • dpnp.random.uniform
        • dpnp.random.vonmises
        • dpnp.random.wald
        • dpnp.random.weibull
        • dpnp.random.zipf
        • dpnp.random.RandomState
        • dpnp.random.seed
      • Set routines
        • dpnp.unique
        • dpnp.unique_all
        • dpnp.unique_counts
        • dpnp.unique_inverse
        • dpnp.unique_values
        • dpnp.isin
      • Sorting, searching, and counting
        • dpnp.sort
        • dpnp.argsort
        • dpnp.sort_complex
        • dpnp.partition
        • dpnp.argmax
        • dpnp.nanargmax
        • dpnp.argmin
        • dpnp.nanargmin
        • dpnp.argwhere
        • dpnp.nonzero
        • dpnp.flatnonzero
        • dpnp.where
        • dpnp.searchsorted
        • dpnp.extract
        • dpnp.count_nonzero
      • Statistics
        • dpnp.ptp
        • dpnp.median
        • dpnp.average
        • dpnp.mean
        • dpnp.std
        • dpnp.var
        • dpnp.nanmedian
        • dpnp.nanmean
        • dpnp.nanstd
        • dpnp.nanvar
        • dpnp.corrcoef
        • dpnp.correlate
        • dpnp.cov
        • dpnp.histogram
        • dpnp.histogram2d
        • dpnp.histogramdd
        • dpnp.bincount
        • dpnp.histogram_bin_edges
        • dpnp.digitize
      • Window functions
        • dpnp.bartlett
        • dpnp.blackman
        • dpnp.hamming
        • dpnp.hanning
        • dpnp.kaiser
    • Routines (SciPy) (dpnp.scipy)
      • Linear algebra (dpnp.scipy.linalg)
        • dpnp.scipy.linalg.lu
        • dpnp.scipy.linalg.lu_factor
        • dpnp.scipy.linalg.lu_solve
      • Special functions (dpnp.scipy.special)
        • dpnp.scipy.special.erf
        • dpnp.scipy.special.erfc
        • dpnp.scipy.special.erfcx
        • dpnp.scipy.special.erfinv
        • dpnp.scipy.special.erfcinv
    • Available array data types
    • Comparison Table NumPy/ DPNP/ CuPy
    • Array API standard compatibility
      • dpnp.__array_namespace_info__
  • Tensor (dpnp.tensor)
  • C++ backend API Reference
Back to top
View this page

Available array data typesΒΆ

Table below shows a list of all supported data types (dtypes) and constants of the Data Parallel Extension for NumPy*.

Data Types

Type aliases

Constants

  • bool

  • int8

  • int16

  • int32

  • int64

  • uint8

  • uint16

  • uint32

  • uint64

  • float32

  • float64

  • complex64

  • complex128

  • bool_

  • byte

  • cdouble

  • csingle

  • double

  • float16

  • int_

  • intc

  • intp

  • longlong

  • single

  • ubyte

  • uintc

  • uintp

  • ushort

  • ulonglong

  • e

  • euler_gamma

  • inf

  • nan

  • pi

Next
Comparison Table NumPy/ DPNP/ CuPy
Previous
dpnp.scipy.special.erfcinv
Copyright © 2020-2026, Intel Corporation
Made with Sphinx and @pradyunsg's Furo