Special functions (dpnp.scipy.special)¶
Error function and Fresnel integrals¶
Calculates the Gauss error function of a given input array. |
|
Calculates the complementary error function of a given input array. |
|
Calculates the scaled complementary error function of a given input array. |
|
Calculates the inverse of the Gauss error function of a given input array. |
|
Calculates the inverse of the complementary error function of a given input array. |