Statistics¶
Order statistics¶
Range of values (maximum - minimum) along an axis. |
Averages and variances¶
Compute the median along the specified axis. |
|
Compute the weighted average along the specified axis. |
|
Compute the arithmetic mean along the specified axis. |
|
Compute the standard deviation along the specified axis. |
|
Compute the variance along the specified axis. |
|
Compute the median along the specified axis, while ignoring NaNs. |
|
Compute the arithmetic mean along the specified axis, ignoring NaNs. |
|
Compute the standard deviation along the specified axis, while ignoring NaNs. |
|
Compute the variance along the specified axis, while ignoring NaNs. |
Correlations¶
Histograms¶
Compute the histogram of a data set. |
|
Compute the bi-dimensional histogram of two data samples. |
|
Compute the multidimensional histogram of some data. |
|
bincount(x, /, weights=None, minlength=0) |
|
Function to calculate only the edges of the bins used by the |
|
Return the indices of the bins to which each value in input array belongs. |