Available array data typesΒΆ
Table below shows a list of all supported data types (dtypes) and constants of the Data Parallel Extension for NumPy*.
Table below shows a list of all supported data types (dtypes) and constants of the Data Parallel Extension for NumPy*.